@@ -30,11 +30,11 @@ class KGameRenderedObjectItemPrivate : public QGraphicsPixmapItem
 		void adjustTransform();
 
 		//QGraphicsItem reimplementations (see comment below for why we need all of this)
-		virtual bool contains(const QPointF& point) const;
-		virtual bool isObscuredBy(const QGraphicsItem* item) const;
-		virtual QPainterPath opaqueArea() const;
-		virtual void paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget* widget = 0);
-		virtual QPainterPath shape() const;
+		bool contains(const QPointF& point) const override;
+		bool isObscuredBy(const QGraphicsItem* item) const override;
+		QPainterPath opaqueArea() const override;
+		void paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget* widget = 0) override;
+		QPainterPath shape() const override;
 	public:
 		KGameRenderedObjectItem* m_parent;
 		QGraphicsView* m_primaryView;
